==> edit-json-file-1.7.2.tgz: edit-json-file/README.md <==
# Installation
> `npm install --save @types/edit-json-file`

# Summary
This package contains type definitions for edit-json-file (https://github.com/IonicaBizau/edit-json-file#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file/index.d.ts)
````ts
/// <reference types= "node" />

import { NoParamCallback } from "fs";
import * as set from "set-value";

declare namespace editJsonFile {
    /** JSON file editor options. */
    interface Options {
        stringify_width?: number | undefined;
        stringify_fn?: ((data: object) => string) | undefined;
        stringify_eol?: boolean | undefined;
        autosave?: boolean | undefined;
        ignore_dots?: boolean | undefined;
    }

    /** JSON file editor. */
    interface JsonEditor {
        /** Get value at path. */
        get(path?: string): any;
        /** Set value at path. */
        set(path: string, value: any, options?: set.Options): JsonEditor;
        /** Appends a value/object to a specific path. */
        append(path: string, value: any): JsonEditor;
        /** Pop an array from a specific path. */
        pop(path: string): JsonEditor;
        /** Unset value at path. */
        unset(path: string): JsonEditor;
        /** Read the JSON file. */
        read(cb?: NoParamCallback): object;
        /** Overwrite the JSON file. */
        write(content: string, cb?: NoParamCallback): JsonEditor;
        /** Empty the JSON file. */
        empty(cb?: NoParamCallback): JsonEditor;
        /** Save the JSON file back to disk. */
        save(cb?: NoParamCallback): JsonEditor;
        /** Get full object. */
        toObject(): object;
    }
}

/** Create a JSON file editor. */
declare function editJsonFile(path: string, options?: editJsonFile.Options): editJsonFile.JsonEditor;

export = editJsonFile;

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 01:17:34 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node), [@types/set-value](https://npmjs.com/package/@types/set-value)

# Credits
These definitions were written by [Twixes](https://github.com/Twixes).

==> edit-json-file-1.7.3.tgz: edit-json-file/README.md <==
# Installation
> `npm install --save @types/edit-json-file`

# Summary
This package contains type definitions for edit-json-file (https://github.com/IonicaBizau/edit-json-file#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file/index.d.ts)
````ts
/// <reference types= "node" />

import { NoParamCallback } from "fs";
import * as set from "set-value";

declare namespace editJsonFile {
    /** JSON file editor options. */
    interface Options {
        stringify_width?: number | undefined;
        stringify_fn?: ((data: object) => string) | undefined;
        stringify_eol?: boolean | undefined;
        autosave?: boolean | undefined;
        ignore_dots?: boolean | undefined;
    }

    /** JSON file editor. */
    interface JsonEditor {
        /** Get value at path. */
        get(path?: string): any;
        /** Set value at path. */
        set(path: string, value: any, options?: set.Options): JsonEditor;
        /** Appends a value/object to a specific path. */
        append(path: string, value: any): JsonEditor;
        /** Pop an array from a specific path. */
        pop(path: string): JsonEditor;
        /** Unset value at path. */
        unset(path: string): JsonEditor;
        /** Read the JSON file. */
        read(cb?: NoParamCallback): object;
        /** Overwrite the JSON file. */
        write(content: string, cb?: NoParamCallback): JsonEditor;
        /** Empty the JSON file. */
        empty(cb?: NoParamCallback): JsonEditor;
        /** Save the JSON file back to disk. */
        save(cb?: NoParamCallback): JsonEditor;
        /** Get full object. */
        toObject(): object;
    }
}

/** Create a JSON file editor. */
declare function editJsonFile(path: string, options?: editJsonFile.Options): editJsonFile.JsonEditor;

export = editJsonFile;

````

### Additional Details
 * Last updated: Mon, 06 Nov 2023 22:41:05 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node), [@types/set-value](https://npmjs.com/package/@types/set-value)

# Credits
These definitions were written by [Twixes](https://github.com/Twixes).
